==> rdmo-0.9.1.tar.gz: rdmo-0.9.1/rdmo/accounts/settings.py <==
GROUPS = (
  ('editor', (
      'add_attributeentity',
      'change_attributeentity',
      'delete_attributeentity',
      'view_attributeentity',
      'add_range',
      'change_range',
      'delete_range',
      'view_range',
      'add_verbosename',
      'change_verbosename',
      'delete_verbosename',
      'view_verbosename',
      'add_attribute',
      'change_attribute',
      'delete_attribute',
      'view_attribute',
      'add_option',
      'change_option',
      'delete_option',
      'view_option',
      'add_optionset',
      'change_optionset',
      'delete_optionset',
      'view_optionset',
      'add_condition',
      'change_condition',
      'delete_condition',
      'view_condition',
      'add_section',
      'change_section',
      'delete_section',
      'view_section',
      'add_catalog',
      'change_catalog',
      'delete_catalog',
      'view_catalog',
      'add_questionentity',
      'change_questionentity',
      'delete_questionentity',
      'view_questionentity',
      'add_subsection',
      'change_subsection',
      'delete_subsection',
      'view_subsection',
      'add_question',
      'change_question',
      'delete_question',
      'view_question',
      'add_task',
      'change_task',
      'delete_task',
      'view_task',
      'add_timeframe',
      'change_timeframe',
      'delete_timeframe',
      'view_timeframe',
      'add_view',
      'change_view',
      'delete_view',
      'view_view',
  )),
  ('reviewer', (
      'view_attributeentity',
      'view_range',
      'view_verbosename',
      'view_attribute',
      'view_option',
      'view_optionset',
      'view_condition',
      'view_section',
      'view_catalog',
      'view_questionentity',
      'view_subsection',
      'view_question',
      'view_task',
      'view_timeframe',
      'view_view',
  )),
  ('api', (
      'view_user',
      'view_attributeentity',
      'view_range',
      'view_verbosename',
      'view_attribute',
      'view_option',
      'view_optionset',
      'view_membership',
      'view_project',
      'view_snapshot',
      'view_value',
      'view_condition',
      'view_section',
      'view_catalog',
      'view_questionentity',
      'view_subsection',
      'view_question',
      'view_task',
      'view_timeframe',
      'view_view',
  ))
)

==> rdmo-0.11.0.tar.gz: rdmo-0.11.0/rdmo/accounts/settings.py <==
GROUPS = (
  ('editor', (
      'add_attribute',
      'change_attribute',
      'delete_attribute',
      'view_attribute',
      'add_option',
      'change_option',
      'delete_option',
      'view_option',
      'add_optionset',
      'change_optionset',
      'delete_optionset',
      'view_optionset',
      'add_condition',
      'change_condition',
      'delete_condition',
      'view_condition',
      'add_section',
      'change_section',
      'delete_section',
      'view_section',
      'add_catalog',
      'change_catalog',
      'delete_catalog',
      'view_catalog',
      'add_questionset',
      'change_questionset',
      'delete_questionset',
      'view_questionset',
      'add_question',
      'change_question',
      'delete_question',
      'view_question',
      'add_question',
      'change_question',
      'delete_question',
      'view_question',
      'add_task',
      'change_task',
      'delete_task',
      'view_task',
      'add_view',
      'change_view',
      'delete_view',
      'view_view',
  )),
  ('reviewer', (
      'view_attribute',
      'view_option',
      'view_optionset',
      'view_condition',
      'view_section',
      'view_catalog',
      'view_questionset',
      'view_question',
      'view_question',
      'view_task',
      'view_view',
  )),
  ('api', (
      'view_user',
      'view_attribute',
      'view_option',
      'view_optionset',
      'view_membership',
      'view_project',
      'view_snapshot',
      'view_value',
      'view_condition',
      'view_section',
      'view_catalog',
      'view_questionset',
      'view_question',
      'view_question',
      'view_task',
      'view_view',
  ))
)
